%define lib_major		40
%define lib_name		%mklibname %{name} %{lib_major}

%define lib_name_devel		%mklibname %{name} -d

Summary:	GLPK glpsol utility
Name:		glpk
Version:	5.0
Release:	%mkrel 1
License:	GPLv3+
Group:		Sciences/Mathematics
URL:		http://www.gnu.org/software/glpk/glpk.html
Source0:	http://ftp.gnu.org/gnu/%{name}/%{name}-%{version}.tar.gz
BuildRequires:	gmp-devel
BuildRequires:	tetex-latex
BuildRequires:	texinfo-tex
BuildRequires:	texlive-dist
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
BuildRequires:  gmp-devel
BuildRequires:  pkgconfig(zlib)
BuildRequires:  suitesparse-devel

# Un-bundle zlib (#1102855). Upstream won't accept; they want to be
# ANSI-compatible, and zlib makes POSIX assumptions.
Patch0:         %{name}-4.65-unbundle-zlib.patch
# Unbundle suitesparse
Patch1:         %{name}-4.65-unbundle-suitesparse.patch
# Fix violations of the ANSI C strict aliasing rules
Patch2:         %{name}-4.65-alias.patch
# See http://lists.gnu.org/archive/html/bug-glpk/2018-03/msg00000.html
Patch3:         %{name}-4.65-sagemath.patch

%description
The GLPK (GNU Linear Programming Kit) package is intended for solving
large-scale linear programming (LP), mixed integer programming (MIP),
and other related problems. It is a set of routines written in ANSI C
and organized in the form of a callable library.

This package contains the utility glpsol.

%package -n %{lib_name}
Summary:	GLPK shared libraries
Group:		Sciences/Mathematics
Obsoletes:	%{name} < %{version}

%description -n %{lib_name}
The GLPK (GNU Linear Programming Kit) package is intended for solving
large-scale linear programming (LP), mixed integer programming (MIP),
and other related problems. It is a set of routines written in ANSI C
and organized in the form of a callable library.

This package contains the library needed to run programs dynamically
linked with GLPK.

%package -n %{lib_name_devel}
Summary:	Header files for development with GLPK
Group:		Development/C
Requires:	%{lib_name} = %{version}-%{release}
Provides:	%{name}-devel = %{version}-%{release}

%description -n %{lib_name_devel}
The GLPK (GNU Linear Programming Kit) package is intended for solving
large-scale linear programming (LP), mixed integer programming (MIP),
and other related problems. It is a set of routines written in ANSI C
and organized in the form of a callable library.

This package contains the headers needed to develop applications using
GLPK.

%package        doc	
Summary:        Documentation for %{name}

%description    doc
Documentation subpackage for %{name}.

%prep
%setup -q

%build
export LIBS=-ldl

# Need to rebuild src/Makefile.in from src/Makefile.am
autoreconf -ifs

%configure --disable-static --with-gmp --enable-dl=dlfcn
# Get rid of undesirable hardcoded rpaths; workaround libtool reordering
# -Wl,--as-needed after all the libraries.
 sed -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
     -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
     -e 's|CC="\(g..\)"|CC="\1 -Wl,--as-needed"|' \
     -i libtool
%make_build

# Trust Knuth to produce a single-pass compiler for a multiple-pass language.
pushd doc
pdflatex -interaction=nonstopmode -file-line-error-style glpk.tex && \
pdflatex -interaction=nonstopmode -file-line-error-style glpk.tex && \
pdflatex -interaction=nonstopmode -file-line-error-style glpk.tex
popd

%install
make install prefix=$RPM_BUILD_ROOT%{_prefix} \
	bindir=$RPM_BUILD_ROOT%{_bindir} libdir=$RPM_BUILD_ROOT%{_libdir} \
	includedir=$RPM_BUILD_ROOT%{_includedir}
rm -f %{buildroot}%{_libdir}/*.la
	
%check
export LD_LIBRARY_PATH="$LD_LIBRARY_PATH:$RPM_BUILD_ROOT%{_libdir}"
make check
## Clean up directories that are included in docs
rm -Rf examples/{.deps,.libs,Makefile*,glpsol,glpsol.o} doc/*.tex

%files
%{_bindir}/glpsol

%files -n %{lib_name}
%{_libdir}/*.so.%{lib_major}{,.*}

%files -n %{lib_name_devel}
%doc examples doc/*.txt doc/*.pdf AUTHORS ChangeLog NEWS README
%license COPYING
%{_includedir}/*
%{_libdir}/*.so

%files doc
%doc doc examples


%changelog
* Fri Dec 18 2020 joequant <joequant> 5.0-1.mga8
+ Revision: 1660562
- update to 5.0

* Mon Feb 17 2020 umeabot <umeabot> 4.65-4.mga8
+ Revision: 1537503
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x

* Thu Oct 31 2019 joequant <joequant> 4.65-3.mga8
+ Revision: 1457124
- add unbundle patches

* Sun Sep 23 2018 umeabot <umeabot> 4.65-2.mga7
+ Revision: 1297918
- Mageia 7 Mass Rebuild

* Tue Mar 27 2018 kekepower <kekepower> 4.65-1.mga7
+ Revision: 1212950
- Update to version 4.65

* Mon Jan 29 2018 daviddavid <daviddavid> 4.64-1.mga7
+ Revision: 1197921
- new version: 4.64
- add missing BR on texlive-dist to fix build

* Tue Aug 15 2017 daviddavid <daviddavid> 4.63-1.mga7
+ Revision: 1141055
- new version: 4.63

* Sat Apr 16 2016 shlomif <shlomif> 4.60-1.mga6
+ Revision: 1002961
- New version 4.60

* Mon Feb 08 2016 umeabot <umeabot> 4.47-6.mga6
+ Revision: 944052
- Mageia 6 Mass Rebuild

* Wed Oct 15 2014 umeabot <umeabot> 4.47-5.mga5
+ Revision: 745712
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 4.47-4.mga5
+ Revision: 679661
- Mageia 5 Mass Rebuild

* Fri Oct 18 2013 umeabot <umeabot> 4.47-3.mga4
+ Revision: 504934
- Mageia 4 Mass Rebuild

* Sat Jan 12 2013 umeabot <umeabot> 4.47-2.mga3
+ Revision: 351838
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sun Dec 11 2011 fwang <fwang> 4.47-1.mga2
+ Revision: 180730
- new version 4.47

* Sun Jan 09 2011 blino <blino> 4.44-2.mga1
+ Revision: 2955
- remove old ldconfig scriptlets
- imported package glpk

